package cn.xbz.zuulfilter;

import com.netflix.zuul.ZuulFilter;
import com.netflix.zuul.context.RequestContext;
import org.springframework.stereotype.Component;

import javax.servlet.http.HttpServletRequest;

@Component
public class MyZuulFilter extends ZuulFilter {

    /**
     * 过滤器类型
     *  pre : 请求路由之前调用
     *  routing : 路由请求时调用
     *  error : 处理请求出错时调用
     *  post : routing和error过滤器之后调用
     */
    @Override
    public String filterType() {
        return "pre";
    }

    /** 执行顺序 , 数字越小优先级越高 , 即越先执行 */
    @Override
    public int filterOrder() {
        return 0;
    }

    /** 是否执行当前过滤器 , 返回false则不执行 */
    @Override
    public boolean shouldFilter() {
        return true;
    }

    /**
     * 过滤器的具体业务
     * ctx.setSendZuulResponse(false)   不再请求路由
     * ctx.setResponseStatusCode(401)   返回的错误码
     * ctx.setResponseBody(body)        返回的body内容
     */
    @Override
    public Object run() {
        RequestContext ctx = RequestContext.getCurrentContext();
        HttpServletRequest request = ctx.getRequest();
        System.out.println(String.format("%s ~~~ %s", request.getMethod(), String.valueOf(request.getRequestURL())));
        Object user = request.getParameter("user");
        if (user == null) {
            System.err.println("error ! no user !");
            ctx.setSendZuulResponse(false);
            ctx.setResponseStatusCode(401);
            try {
                ctx.getResponse().getWriter().write("error ! no user !");
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
        System.out.println("~ over ~");
        return null;
    }
}